## Resources
- http://techblog.tilllate.com/2008/07/20/ten-methods-to-obfuscate-e-mail-addresses-compared/
- http://csarven.ca/hiding-email-addresses
- https://en-gb.wordpress.org/plugins/obfuscate-email/
- https://wordpress.org/plugins/email-address-encoder/
- http://bacsoftwareconsulting.com/blog/index.php/wordpress-cat/how-to-obfuscate-email-addresses-in-wordpress-without-a-plugin/
- https://github.com/craigerm/email-obfuscate-octopress
- https://perishablepress.com/best-method-for-email-obfuscation/
- http://www.grall.name/posts/1/antiSpam-emailAddressObfuscation.html
- https://github.com/morninj/django-email-obfuscator

## Methods
- unicode encoding, entity encoding, urlencode, hex values
- CSS `:after`, CSS bidi
- CSS display none for fillers
- intersperse inline tags (`span`, etc.)
- generate using JS
- email as image, canvas?
- http://www.unphp.net/decode/5c87a622cf1276077cff9d8400c0c9fc/
- https://stackoverflow.com/questions/10172499/mailto-using-javascript
